==> kameleoon_client_flutter-0.0.1.tar.gz: example/lib/Pages/Login/login_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:kameleoon_client_flutter/kameleoon_client.dart';
import 'package:kameleoon_client_flutter/kameleoon_exceptions.dart' as KameleoonExceptions;
import 'package:kameleoon_client_flutter_example/Components/Button.dart';
import 'package:kameleoon_client_flutter_example/Pages/Signup/signup_page.dart';

import '../../constants.dart';
import 'package:kameleoon_client_flutter_example/Components/KTextInput.dart';

class LoginPage extends StatefulWidget {
  @override
  _LoginPage createState() => _LoginPage();
}

class _LoginPage extends State<LoginPage> {
  @override
  void initState() {
    super.initState();
    initKameleoon();
  }

  Future<void> initKameleoon() async {
    KameleoonClient client = await KameleoonClient.create("yjiu8jw554");

    client.runWhenReady(() async {
      String visitorCode = await client.obtainVisitorCode();
      try {
        bool ff = await client.activateFeature(visitorCode, "color-feature-flag");
        if (ff) {
          String color = await client.obtainFeatureVariable("color-feature-flag", "color");
          color = "FF" + color.toUpperCase().replaceAll("#", "");
          //mainColor = Color(int.parse(color, radix: 16));
        }
      } on KameleoonExceptions.FeatureConfigurationNotFound {
      } on KameleoonExceptions.NotTargeted {
      } on PlatformException {
      }
    }, () {}, 5000);
  }

  @override
  Widget build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;
    return Scaffold(
      body: Container(
          width: screenSize.width,
          height: screenSize.height,
          child: Column(
            children: <Widget>[
              Padding(
                  padding: EdgeInsets.only(bottom: 20, top: 70),
                  child: Image.asset(
                    "assets/images/logo.png",
                  )
              ),
              Text(
                "Welcome back!",
                style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: 24,
                ),
              ),
              Padding(
                  padding: EdgeInsets.only(top: 10, bottom: 50),
                  child: Text(
                      "Sign in to access your account",
                      style: TextStyle(
                          fontWeight: FontWeight.w400,
                          fontSize: 17
                      )
                  )
              ),
              Text(
                "Username or e-mail address",
                textAlign: TextAlign.left,
                style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: 14
                )
              ),
              Padding(
                  padding: EdgeInsets.only(bottom: 20, top: 5),
                  child: KTextInput(
                    suffixIcon: false,
                    icon: Icons.person,
                    hint: "Username or Email"
                  )
              ),
              Text(
                  "Password",
                  textAlign: TextAlign.left,
                  style: TextStyle(
                      fontWeight: FontWeight.bold,
                      fontSize: 14
                  )
              ),
              Padding(
                  padding: EdgeInsets.only(bottom: 30, top: 5),
                  child: KTextInput(
                    suffixIcon: true,
                    icon: Icons.lock,
                    hint: "Password"
                  )
              ),
              Button(
                text: "Log in",
                bgColor: mainColor,
                borderColor: mainColor,
                borderWidth: 0,
                borderStyle: BorderStyle.none,
                textColor: Colors.white,
              ),
              Padding(
                  padding: EdgeInsets.only(top: 5),
                  child: Button(
                      text: "Don't have an account?",
                      bgColor: Colors.transparent,
                      borderColor: mainColor,
                      borderWidth: 0,
                      borderStyle: BorderStyle.none,
                      textColor: Color.fromRGBO(0, 0, 0, 0.5),
                      onPress: () {
                        Navigator.push(
                            context, MaterialPageRoute(builder: (context) {
                          return SignupPage();
                        }));
                      }
                    ),
              ),
            ],
          )
      )
    );
  }
}

==> kameleoon_client_flutter-1.0.3.tar.gz: example/lib/Pages/Login/login_page.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:kameleoon_client_flutter/kameleoon_client_flutter.dart';

import 'package:kameleoon_client_flutter_example/Components/Button.dart';
import 'package:kameleoon_client_flutter_example/Pages/Signup/signup_page.dart';

import '../../constants.dart';
import 'package:kameleoon_client_flutter_example/Components/KTextInput.dart';

class LoginPage extends StatefulWidget {
  @override
  _LoginPage createState() => _LoginPage();
}

class _LoginPage extends State<LoginPage> {
  String _welcome = "Welcome";
  @override
  void initState() {
    super.initState();
    initKameleoon();
  }

  Future<void> initKameleoon() async {
    KameleoonClient? client = KameleoonClientFactory.create("yjiu8jw554");
    print("initKameleoon");

    client!.runWhenReady(() async {
      print("ready");
      String? visitorCode = await client.obtainVisitorCode();
      try {
        bool? ff = await client.activateFeature(visitorCode!, "color-feature-flag");
        if (ff == true) {
          String? color = await client.obtainFeatureVariable("color-feature-flag", "color") as String?;
          color = "FF" + color!.toUpperCase().replaceAll("#", "");
          mainColor = Color(int.parse(color, radix: 16));
        }
      } on FeatureConfigurationNotFound {
      } on NotTargeted {
      } on PlatformException {
      }

      try {
        int? variationID = await client.triggerExperiment(visitorCode!, 130865);
        dynamic json = await client.obtainVariationAssociatedData(variationID!);
        setState(() {
          _welcome = json["text"];
        });
      } on ExperimentConfigurationNotFound {
      } on NotTargeted {
      } on PlatformException {
      }
    }, () {
      print("timeout");
    }, 5000);
  }

  @override
  Widget build(BuildContext context) {
    Size screenSize = MediaQuery.of(context).size;
    return Scaffold(
      body: Container(
          width: screenSize.width,
          height: screenSize.height,
          child: Column(
            children: <Widget>[
              Padding(
                  padding: EdgeInsets.only(bottom: 20, top: 70),
                  child: Image.asset(
                    "assets/images/logo.png",
                  )
              ),
              Text(
                "$_welcome",
                style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: 24,
                ),
              ),
              Padding(
                  padding: EdgeInsets.only(top: 10, bottom: 50),
                  child: Text(
                      "Login page",
                      style: TextStyle(
                          fontWeight: FontWeight.w400,
                          fontSize: 17
                      )
                  )
              ),
              Text(
                "Username or e-mail address",
                textAlign: TextAlign.left,
                style: TextStyle(
                  fontWeight: FontWeight.bold,
                  fontSize: 14
                )
              ),
              Padding(
                  padding: EdgeInsets.only(bottom: 20, top: 5),
                  child: KTextInput(
                    suffixIcon: false,
                    icon: Icons.person,
                    hint: "Username or Email"
                  )
              ),
              Text(
                  "Password",
                  textAlign: TextAlign.left,
                  style: TextStyle(
                      fontWeight: FontWeight.bold,
                      fontSize: 14
                  )
              ),
              Padding(
                  padding: EdgeInsets.only(bottom: 30, top: 5),
                  child: KTextInput(
                    suffixIcon: true,
                    icon: Icons.lock,
                    hint: "Password"
                  )
              ),
              Button(
                text: "Log in",
                bgColor: mainColor,
                borderColor: mainColor,
                borderWidth: 0,
                borderStyle: BorderStyle.none,
                textColor: Colors.white,
              ),
              Padding(
                  padding: EdgeInsets.only(top: 5),
                  child: Button(
                      text: "Don't have an account?",
                      bgColor: Colors.transparent,
                      borderColor: mainColor,
                      borderWidth: 0,
                      borderStyle: BorderStyle.none,
                      textColor: Color.fromRGBO(0, 0, 0, 0.5),
                      onPress: () {
                        Navigator.push(
                            context, MaterialPageRoute(builder: (context) {
                          return SignupPage();
                        }));
                      }
                    ),
              ),
            ],
          )
      )
    );
  }
}
